;;; Copyright (C) 1991 Christopher J. Love
;;;
;;; This file is for use with Epoch, a modified version of GNU Emacs.
;;; Requires Epoch 4.0 or later.
;;;
;;; This code is distributed in the hope that it will be useful,
;;; bute WITHOUT ANY WARRANTY. No author or distributor accepts
;;; responsibility to anyone for the consequences of using this code
;;; or for whether it serves any particular purpose or works at all,
;;; unless explicitly stated in a written agreement.
;;;
;;; Everyone is granted permission to copy, modify and redistribute
;;; this code, but only under the conditions described in the
;;; GNU Emacs General Public License, except the original author nor his
;;; agents are bound by the License in their use of this code.
;;; (These special rights for the author in no way restrict the rights of
;;;  others given in the License or this prologue)
;;; A copy of this license is supposed to have been given to you along
;;; with Epoch so you can know your rights and responsibilities. 
;;; It should be in a file named COPYING.  Among other things, the
;;; copyright notice and this notice must be preserved on all copies. 
;;;
;;; $Revision: 1.1 $
;;; $Source: /import/kaplan/stable/distrib/epoch-4.0/epoch-lisp/RCS/button.el,v $
;;; $Date: 91/04/26 10:03:25 $
;;; $Author: love $
;;;
(require 'mini-cl)
(provide 'button)

(defun epoch::add-button (start end style &optional data buffer)
  "Adds a button to from START to END having STYLE and DATA in an optional BUFFER. START and END should be markers or integers. STYLE must be a style or nil.  DATA can be any lisp object. Returns the button if successful."
  (let
    (
      (button (epoch::move-button (epoch::make-button) start end buffer))
    )
    (when button
      (epoch::set-button-data button data)
      (epoch::set-button-style button style)
    )
    button
  )
)
(fset 'add-button (symbol-function 'epoch::add-button))
;;; --------------------------------------------------------------------------
;;; some utility functions
;;;
(defun add-read-only-button (start end style &optional data buffer)
  (set-button-read-only
    (add-button start end style data buffer)
    t
  )
)
;;;
(defun button-text (&optional button)
"Returns the text contained inside the BUTTON as a string."
  (and button (not (buttonp button))
    (signal 'wrong-type-argument (list 'buttonp button))
  )
  (setq button (or button (button-at)))
  (let
    (
      (buff (and button (button-buffer button)))
    )
    (if (bufferp buff)
      (save-excursion
	(set-buffer buff)
	(buffer-substring (button-start button) (button-end button))
      )
      ""
    )
  )
)
